@@ -204,6 +204,7 @@ def read_SPOSCAR_and_masses(file, n_atom_conventional_cell,n_atom_primitive_cell
     
     N = len(S[:,0])
     tot_atoms_primitive = int(np.sum(n_atom_primitive_cell))
+
     N1N2N3 = int(N/tot_atoms_primitive)
     
     if (conv==1.0):
@@ -218,7 +219,7 @@ def read_SPOSCAR_and_masses(file, n_atom_conventional_cell,n_atom_primitive_cell
     for i in range(len(n_atom_conventional_cell)):
         n = n_atom_conventional_cell[i]
         for j in range(n):
-            Ruc[i] = R0[i*(j+1)*N1N2N3]
+            Ruc[i+j] = R0[(i+j)*N1N2N3]
     R0 = np.repeat(R0,3,axis=0)
     
     
